@@ -189,7 +189,8 @@ mod test {
 	#[test]
 	fn setup_and_prove_mixer_groth16() {
 		let rng = &mut test_rng();
-		let (circuit, .., public_inputs) = setup_random_circuit::<_, BlsFr>(rng);
+		let curve = Curve::Bls381;
+		let (circuit, .., public_inputs) = setup_random_circuit::<_, BlsFr>(rng, curve);
 
 		let (pk, vk) = setup_groth16::<_, Bls12_381>(rng, circuit.clone());
 		let proof = prove_groth16::<_, Bls12_381>(&pk, circuit, rng);
@@ -202,7 +203,8 @@ mod test {
 	#[test]
 	fn should_fail_with_invalid_public_inputs() {
 		let rng = &mut test_rng();
-		let (circuit, .., public_inputs) = setup_random_circuit(rng);
+		let curve = Curve::Bls381;
+		let (circuit, .., public_inputs) = setup_random_circuit(rng, curve);
 
 		type GrothSetup = Groth16<Bls12_381>;
 
@@ -219,13 +221,14 @@ mod test {
 	#[test]
 	fn should_fail_with_invalid_root() {
 		let rng = &mut test_rng();
-		let params5 = setup_params_5();
+		let curve = Curve::Bls381;
+		let params5 = setup_params_5(curve);
 		let relayer = BlsFr::rand(rng);
 		let recipient = BlsFr::rand(rng);
 		let (leaf_private, leaf, nullifier_hash) = setup_leaf(&params5, rng);
 
 		let arbitrary_input = setup_arbitrary_data(recipient, relayer);
-		let params3 = setup_params_3();
+		let params3 = setup_params_3(curve);
 		let (_, path) = setup_tree_and_create_path(&[leaf], 0, &params3);
 		let root = BlsFr::rand(rng);
 
@@ -254,13 +257,14 @@ mod test {
 	#[test]
 	fn should_fail_with_invalid_leaf() {
 		let rng = &mut test_rng();
-		let params5 = setup_params_5();
+		let curve = Curve::Bls381;
+		let params5 = setup_params_5(curve);
 		let relayer = BlsFr::rand(rng);
 		let recipient = BlsFr::rand(rng);
 		let (leaf_private, _, nullifier_hash) = setup_leaf(&params5, rng);
 		let leaf = BlsFr::rand(rng);
 		let arbitrary_input = setup_arbitrary_data(recipient, relayer);
-		let params3 = setup_params_3();
+		let params3 = setup_params_3(curve);
 		let (_, path) = setup_tree_and_create_path(&[leaf], 0, &params3);
 		let root = BlsFr::rand(rng);
 
@@ -289,13 +293,14 @@ mod test {
 	#[test]
 	fn should_fail_with_invalid_nullifier() {
 		let rng = &mut test_rng();
-		let params5 = setup_params_5();
+		let curve = Curve::Bls381;
+		let params5 = setup_params_5(curve);
 		let relayer = BlsFr::rand(rng);
 		let recipient = BlsFr::rand(rng);
 		let (leaf_private, leaf, _) = setup_leaf(&params5, rng);
 		let nullifier_hash = BlsFr::rand(rng);
 		let arbitrary_input = setup_arbitrary_data(recipient, relayer);
-		let params3 = setup_params_3();
+		let params3 = setup_params_3(curve);
 		let (_, path) = setup_tree_and_create_path(&[leaf], 0, &params3);
 		let root = BlsFr::rand(rng);
 
