@@ -65,9 +65,10 @@ pub fn setup_circuit<R: Rng, F: PrimeField>(
 	recipient: F,
 	relayer: F,
 	rng: &mut R,
+	curve: Curve,
 ) -> (Circuit<F>, F, F, F, Vec<F>) {
-	let params3 = setup_params_3::<F>();
-	let params5 = setup_params_5::<F>();
+	let params3 = setup_params_3::<F>(curve);
+	let params5 = setup_params_5::<F>(curve);
 
 	let arbitrary_input = setup_arbitrary_data::<F>(recipient, relayer);
 	let (leaf_private, leaf, nullifier_hash) = setup_leaf::<R, F>(&params5, rng);
@@ -90,12 +91,12 @@ pub fn setup_circuit<R: Rng, F: PrimeField>(
 	(mc, leaf, nullifier_hash, root, public_inputs)
 }
 
-pub fn setup_random_circuit<R: Rng, F: PrimeField>(rng: &mut R) -> (Circuit<F>, F, F, F, Vec<F>) {
+pub fn setup_random_circuit<R: Rng, F: PrimeField>(rng: &mut R, curve: Curve) -> (Circuit<F>, F, F, F, Vec<F>) {
 	let leaves = Vec::new();
 	let index = 0;
 	let recipient = F::rand(rng);
 	let relayer = F::rand(rng);
-	setup_circuit(&leaves, index, recipient, relayer, rng)
+	setup_circuit(&leaves, index, recipient, relayer, rng, curve)
 }
 
 pub fn get_public_inputs<F: PrimeField>(
@@ -130,8 +131,9 @@ pub fn setup_groth16<R: RngCore + CryptoRng, E: PairingEngine>(
 
 pub fn setup_random_groth16<R: RngCore + CryptoRng, E: PairingEngine>(
 	rng: &mut R,
+	curve: Curve,
 ) -> (ProvingKey<E>, VerifyingKey<E>) {
-	let (circuit, ..) = setup_random_circuit::<R, E::Fr>(rng);
+	let (circuit, ..) = setup_random_circuit::<R, E::Fr>(rng, curve);
 	let (pk, vk) = Groth16::<E>::circuit_specific_setup(circuit.clone(), rng).unwrap();
 	(pk, vk)
 }
@@ -159,16 +161,17 @@ mod test {
 	#[test]
 	fn should_create_setup() {
 		let mut rng = test_rng();
+		let curve = Curve::Bls381;
 		let recipient = Bls381::from(0u8);
 		let relayer = Bls381::from(0u8);
 		let leaves = Vec::new();
 		let (circuit, leaf, nullifier, root, public_inputs) =
-			setup_circuit::<_, Bls381>(&leaves, 0, recipient, relayer, &mut rng);
+			setup_circuit::<_, Bls381>(&leaves, 0, recipient, relayer, &mut rng, curve);
 
 		add_members_mock(vec![leaf]);
 
 		// let (pk, vk) = setup_circuit_groth16(&mut rng, circuit.clone());
-		let (pk, vk) = setup_random_groth16::<_, Bls12_381>(&mut rng);
+		let (pk, vk) = setup_random_groth16::<_, Bls12_381>(&mut rng, curve);
 		let proof = prove_groth16::<_, Bls12_381>(&pk, circuit.clone(), &mut rng);
 		let res = verify_groth16::<Bls12_381>(&vk, &public_inputs, &proof);
 
@@ -189,12 +192,13 @@ mod test {
 	#[test]
 	fn should_create_longer_setup() {
 		let mut rng = test_rng();
+		let curve = Curve::Bls381;
 		let recipient = Bls381::from(0u8);
 		let relayer = Bls381::from(0u8);
 		let leaves = Vec::new();
 
-		let params3 = setup_params_3::<Bls381>();
-		let params5 = setup_params_5::<Bls381>();
+		let params3 = setup_params_3::<Bls381>(curve);
+		let params5 = setup_params_5::<Bls381>(curve);
 
 		let arbitrary_input = setup_arbitrary_data::<Bls381>(recipient, relayer);
 		let (leaf_private, leaf, nullifier_hash) = setup_leaf::<_, Bls381>(&params5, &mut rng);
@@ -217,7 +221,7 @@ mod test {
 		add_members_mock(vec![leaf]);
 
 		// let (pk, vk) = setup_circuit_groth16(&mut rng, circuit.clone());
-		let (pk, vk) = setup_random_groth16::<_, Bls12_381>(&mut rng);
+		let (pk, vk) = setup_random_groth16::<_, Bls12_381>(&mut rng, curve);
 		let proof = prove_groth16::<_, Bls12_381>(&pk, mc.clone(), &mut rng);
 		let res = verify_groth16::<Bls12_381>(&vk, &public_inputs, &proof);
 
@@ -238,16 +242,17 @@ mod test {
 	#[test]
 	fn should_handle_proof_deserialization() {
 		let mut rng = test_rng();
+		let curve = Curve::Bls381;
 		let recipient = Bls381::from(0u8);
 		let relayer = Bls381::from(0u8);
 		let leaves = Vec::new();
 		let (circuit, leaf, nullifier, root, public_inputs) =
-			setup_circuit(&leaves, 0, recipient, relayer, &mut rng);
+			setup_circuit(&leaves, 0, recipient, relayer, &mut rng, curve);
 
 		add_members_mock(vec![leaf]);
 
 		// let (pk, vk) = setup_circuit_groth16(&mut rng, circuit.clone());
-		let (pk, vk) = setup_random_groth16::<_, Bls12_381>(&mut rng);
+		let (pk, vk) = setup_random_groth16::<_, Bls12_381>(&mut rng, curve);
 		let proof = prove_groth16::<_, Bls12_381>(&pk, circuit.clone(), &mut rng);
 		let mut proof_bytes = vec![0u8; proof.serialized_size()];
 		proof.serialize(&mut proof_bytes[..]).unwrap();
